==> alt-ergo_0.95.2.orig.tar.gz: alt-ergo-0.95.2/src/preprocess/cnf.mli <==
(******************************************************************************)
(*     The Alt-Ergo theorem prover                                            *)
(*     Copyright (C) 2006-2013                                                *)
(*     CNRS - INRIA - Universite Paris Sud                                    *)
(*                                                                            *)
(*     Sylvain Conchon                                                        *)
(*     Evelyne Contejean                                                      *)
(*                                                                            *)
(*     Francois Bobot                                                         *)
(*     Mohamed Iguernelala                                                    *)
(*     Stephane Lescuyer                                                      *)
(*     Alain Mebsout                                                          *)
(*     Claire Dross                                                           *)
(*                                                                            *)
(*   This file is distributed under the terms of the CeCILL-C licence         *)
(******************************************************************************)

open Why_ptree

val make : ((int tdecl, int) annoted * bool) list -> sat_tdecl Queue.t

(* For the formulas of a theory. Simplify future handling by applying
   DeMorgan rules. A formula is a conjuction of disjunctions of a literal
   and a formula or a quantified formula. The order of the input is preserved.
*)
val make_theory : ((int tdecl, int) annoted * bool) list -> sat_tdecl Queue.t

==> alt-ergo_0.99.1+dfsg1.orig.tar.gz: alt-ergo-0.99.1/src/preprocess/cnf.mli <==
(******************************************************************************)
(*     Alt-Ergo: The SMT Solver For Software Verification                     *)
(*     Copyright (C) 2013-2014 --- OCamlPro                                   *)
(*     This file is distributed under the terms of the CeCILL-C licence       *)
(******************************************************************************)

(******************************************************************************)
(*     The Alt-Ergo theorem prover                                            *)
(*     Copyright (C) 2006-2013                                                *)
(*     CNRS - INRIA - Universite Paris Sud                                    *)
(*                                                                            *)
(*     Sylvain Conchon                                                        *)
(*     Evelyne Contejean                                                      *)
(*                                                                            *)
(*     Francois Bobot                                                         *)
(*     Mohamed Iguernelala                                                    *)
(*     Stephane Lescuyer                                                      *)
(*     Alain Mebsout                                                          *)
(*                                                                            *)
(*   This file is distributed under the terms of the CeCILL-C licence         *)
(******************************************************************************)

open Why_ptree

val make : ((int tdecl, int) annoted * bool) list -> sat_tdecl Queue.t
